@@ -2,7 +2,7 @@ from .player import Player
 
 class Team(object):
     '''Teams are part of the league'''
-    def __init__(self, data, roster, member, schedule, year):
+    def __init__(self, data, roster, member, schedule, year, **kwargs):
         self.team_id = data['id']
         self.team_abbrev = data['abbrev']
         self.team_name = "%s %s" % (data['location'], data['nickname'])
@@ -13,6 +13,10 @@ class Team(object):
         self.ties = data['record']['overall']['ties']
         self.points_for = data['record']['overall']['pointsFor']
         self.points_against = round(data['record']['overall']['pointsAgainst'], 2)
+        self.acquisitions = data.get('transactionCounter', {}).get('acquisitions', 0)
+        self.acquisition_budget_spent = data.get('transactionCounter', {}).get('acquisitionBudgetSpent', 0)
+        self.drops = data.get('transactionCounter', {}).get('drops', 0)
+        self.trades = data.get('transactionCounter', {}).get('trades', 0)
         self.playoff_pct = data.get('currentSimulationResults', {}).get('playoffPct', 0) * 100
         self.draft_projected_rank = data.get('draftDayProjectedRank', 0)
         self.owner = 'None'
